@@ -1,4 +1,4 @@
-/* $Id: nano.c,v 1.144 2001/04/02 05:36:08 astyanax Exp $ */
+/* $Id: nano.c,v 1.144.2.3 2001/05/05 17:38:31 astyanax Exp $ */
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -19,6 +19,8 @@
  *                                                                        *
  **************************************************************************/
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -38,7 +40,6 @@
 #include <limits.h>
 #include <assert.h>
 
-#include "config.h"
 #include "proto.h"
 #include "nano.h"
 
@@ -69,7 +70,7 @@ static char *alt_speller;	/* Alternative spell command */
 #endif
 
 struct termios oldterm;		/* The user's original term settings */
-static struct sigaction act;	/* For all out fun signal handlers */
+static struct sigaction act;	/* For all our fun signal handlers */
 
 #ifndef DISABLE_HELP
 static char *help_text_init = ""; /* Initial message, not including shortcuts */
@@ -621,7 +622,7 @@ int do_enter(filestruct * inptr)
 
     /* The logic here is as follows:
      *    -> If we are at the bottom of the buffer, we want to recenter
-     *       (read: rebuild) the screen and forcably move the cursor.
+     *       (read: rebuild) the screen and forcibly move the cursor.
      *    -> otherwise, we want simply to redraw the screen and update
      *       where we think the cursor is.
      */
@@ -993,7 +994,7 @@ void do_wrap(filestruct * inptr, char input_char)
 
 
     totlines++;
-    /* Everything about it makes me want this line here but it causes
+    /* Everything about it makes me want this line here, but it causes
      * totsize to be high by one for some reason.  Sigh. (Rob) */
     /* totsize++; */
 	
@@ -1057,7 +1058,7 @@ void check_wrap(filestruct * inptr, char ch)
 #endif /* DISABLE_WRAPPING */
 
 /* Stuff we do when we abort from programs and want to clean up the
- * screen.  This doesnt do much right now.
+ * screen.  This doesn't do much right now.
  */
 void do_early_abort(void)
 {
@@ -1148,7 +1149,7 @@ int do_delete(void)
 
 	align(&current->data);
 
-    /* Now that we have a magic lnie again, we can check for both being
+    /* Now that we have a magic line again, we can check for both being
        on the line before filebot as well as at filebot */
     } else if (current->next != NULL && current->next != filebot) {
 	current->data = nrealloc(current->data,
@@ -1306,7 +1307,7 @@ int do_int_speller(char *tempfile_name)
 	}
 	close(in_fd[1]);
 
-	/* Start spell program, we are using the PATH here!?!? */
+	/* Start spell program; we are using the PATH here!?!? */
 	execlp("spell", "spell", NULL);
 
 	/* Should not be reached, if spell is found!!! */
@@ -1698,7 +1699,7 @@ void handle_sigwinch(int s)
 void signal_init(void)
 {
 
-    /* Trap SIGINT and SIGQUIT  cuz we want them to do useful things. */
+    /* Trap SIGINT and SIGQUIT cuz we want them to do useful things. */
     memset(&act, 0, sizeof(struct sigaction));
     act.sa_handler = SIG_IGN;
     sigaction(SIGINT, &act, NULL);
@@ -1714,7 +1715,7 @@ void signal_init(void)
     }
 
 
-    /* Trap SIGHUP  cuz we want to write the file out. */
+    /* Trap SIGHUP cuz we want to write the file out. */
     act.sa_handler = handle_hup;
     sigaction(SIGHUP, &act, NULL);
 
@@ -1728,7 +1729,7 @@ void window_init(void)
     if ((editwinrows = LINES - 5 + no_help()) < MIN_EDITOR_ROWS)
 	die_too_small();
 
-    /* Setup up the main text window */
+    /* Set up the main text window */
     edit = newwin(editwinrows, COLS, 2, 0);
 
     /* And the other windows */
@@ -1981,7 +1982,7 @@ int do_justify(void)
     display_main_list();
     reset_cursor();
 
-    /* Now get a keystroke and see if it's unjustify, if not unget the keytroke 
+    /* Now get a keystroke and see if it's unjustify; if not, unget the keystroke 
        and return */
     if ((kbinput = wgetch(edit)) != NANO_UNJUSTIFY_KEY) {
 	ungetch(kbinput); 
@@ -1999,7 +2000,7 @@ int do_justify(void)
 	if (tmptop->prev == NULL)
 	    edit_refresh();
 
-	/* Restore totsize from befure justify */
+	/* Restore totsize from before justify */
 	totsize = totbak;
 	free_filestruct(tmptop);
 	blank_statusbar_refresh();
@@ -2135,8 +2136,8 @@ void do_toggle(int which)
 #endif
 }
 
-/* If the NumLock key has made the keypad gone awry, print an error
-   message, hopefully we can address it later. */
+/* If the NumLock key has made the keypad go awry, print an error
+   message; hopefully we can address it later. */
 void print_numlock_warning(void)
 {
     static int didmsg = 0;
@@ -2154,12 +2155,16 @@ int ABCD(int input)
     switch(input)
     {                
 	case 'A':
+	case 'a':
 	    return(KEY_UP);
 	case 'B':
+	case 'b':
 	    return(KEY_DOWN);
 	case 'C':
+	case 'c':
 	    return(KEY_RIGHT);
 	case 'D': 
+	case 'd': 
 	    return(KEY_LEFT);
 	default:
 	    return 0;
@@ -2372,7 +2377,7 @@ int main(int argc, char *argv[])
 #ifdef DEBUG
     fprintf(stderr, _("Main: bottom win\n"));
 #endif
-    /* Set up up bottom of window */
+    /* Set up bottom of window */
     display_main_list();
 
 #ifdef DEBUG
@@ -2420,7 +2425,8 @@ int main(int argc, char *argv[])
 		/* Alt-O, suddenly very important ;) */
 	    case 79:
 		kbinput = wgetch(edit);
-		if (kbinput <= 'D' && kbinput >= 'A')
+		if ((kbinput <= 'D' && kbinput >= 'A') || 
+		    (kbinput <= 'd' && kbinput >= 'a'))
 		   kbinput = ABCD(kbinput);
 		else if (kbinput <= 'z' && kbinput >= 'j')
 		    print_numlock_warning();
@@ -2482,7 +2488,7 @@ int main(int argc, char *argv[])
 			wgetch(edit);
 			break;
 		    case 126:	/* Hack, make insert key do something 
-				   usefile, like insert file */
+				   useful, like insert file */
 			do_insertfile();
 			keyhandled = 1;
 			break;
@@ -2520,6 +2526,10 @@ int main(int argc, char *argv[])
 		case 'B':
 		case 'C':
 		case 'D':
+		case 'a':
+		case 'b':
+		case 'c':
+		case 'd':
 		    kbinput = ABCD(kbinput);
 		    break;
 		case 'H':
